@@ -8,6 +8,73 @@ binarizeNetwork <- function(network) {
 }
 
 
+# checkProcessState
+checkProcessState <- function(state) {
+  
+  # extract dependent variable
+  dep.var <- state$dep.var
+  
+  # make sure that dependent variable has corresponding edgelist
+  if (!(dep.var %in% names(state))) {
+    stop("Dependent variable has no corresponding edgelist in the state object.")
+  }
+  
+  # is edgelist of class 'edgelist.monan'?
+  if (!(inherits(state[[dep.var]], "edgelist.monan"))) {
+    stop("Dependent variable is not of class 'edgelist.monan'.")
+  }
+  
+  
+  # extract nodeset names defined in edgelist
+  nodesets <- c()
+  nodesets[1] <- state[[dep.var]]$nodeSet[1]
+  nodesets[2] <- state[[dep.var]]$nodeSet[2]
+  nodesets[3] <- state[[dep.var]]$nodeSet[3]
+  
+  # do nodeset names from edgelist have a corresponding nodeset and are they of class 'nodeset.monan'?
+  for (i in 1:length(nodesets)) {
+    if (!(nodesets[i] %in% names(state))) {
+      stop(paste(nodesets[i], "has no corresponding object.",
+                 "Nodesets specified in the edgelist must have a corresponding object with the same name."))
+    }
+    if (!(inherits(state[[nodesets[i]]], "nodeSet.monan"))) {
+      stop(paste(nodesets[i], "is not of class 'nodeSet.monan'."))
+    }
+  }
+  
+  # do dependent variable and individual nodeset have the same number of observations?
+  if (!(dim(state[[dep.var]]$data)[1] == length(state[[nodesets[3]]]$ids))) {
+    stop("Dependent variable and individual nodeset do not have the same number of observations.")
+  }
+  
+  # extract covar names
+  covars <- names(state)[!(names(state) %in% c(dep.var, nodesets, "dep.var"))]
+  
+  # if there are covars, check them
+  if (length(covars) != 0) {
+    
+    # are covars of class 'nodeVar.monan' or 'network.monan'? do they have correctly
+    # specified nodeset names and are these nodesets of the correct size?
+    for (i in 1:length(covars)) {
+      #class
+      if (!(inherits(state[[covars[i]]], "nodeVar.monan") || 
+            inherits(state[[covars[i]]], "network.monan"))) {
+        stop(paste(covars[i], "must either be of class 'nodeVar.monan' or 'network.monan'."))
+      }
+      # nodeset names
+      if (!(all(state[[covars[i]]]$nodeSet %in% names(state)))) {
+        stop(paste("The nodeset of covar '", covars[i], "' has no corresponding object.",
+                   "Nodesets assigned when creating covars must have a corresponding object with the same name."           ))
+      }
+      # nodeset sizes
+      if (!(state[[covars[i]]]$size[1] == length(state[[state[[covars[i]]]$nodeSet[1]]]$ids))) {
+        stop(paste("The covar '", covars[i], "' is not of the same size as its assigned nodeset."))
+      }
+    }
+  }
+}
+
+
 # getCovarianceMatrix
 getCovarianceMatrix <- function(statistics) {
   meanStatistics <- colMeans(statistics)
